package Perinci::CmdLine::dux::I18N;
use parent 'Perinci::CmdLine::I18N';

our $VERSION = '1.37'; # VERSION

1;
# ABSTRACT: Project class for Perinci::CmdLine::dux

__END__

=pod

=encoding utf-8

=head1 NAME

Perinci::CmdLine::dux::I18N - Project class for Perinci::CmdLine::dux

=head1 VERSION

version 1.37

=head1 DESCRIPTION

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-dux>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-dux>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dux>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
